@@ -11,7 +11,7 @@
 '''
 
 import json
-
+import glob
 from joblib import Parallel, delayed
 import copy
 import os
@@ -152,7 +152,7 @@ class BaseProvider:
         """
         return DatasetD.dataset_info(dataset)
 
-    def datasets(self, dataset=None, instruments="all", fields=None, start_time=None, end_time=None):
+    def datasets(self, dataset, instruments="all", fields=None, start_time=None, end_time=None):
         """
         :param instruments: instruments list or market (ei. "zz500", "hs300", "zz800", "zz1000", "all"
         :param fields:  features str or list
@@ -565,7 +565,7 @@ class DatasetProvider(BaseDataProvider):
         return data
 
     def dataset_info(self, dataset):
-        config_path = self._uri_data.format(dataset) + "_config.json"
+        config_path = os.path.join(self._uri_data.format(dataset),  "config.json")
         return DatasetD.read_config(config_path)
 
     @staticmethod
@@ -580,7 +580,7 @@ class DatasetProvider(BaseDataProvider):
         """
         # One process for one task, so that the memory will be freed quicker.
         normalize_column_names = DatasetD.normalize_cache_fields(column_names)
-        config_path = fpath + "_config.json"
+        config_path = os.path.join(fpath, "config.json")
         code_flt, time_flt, _, is_annrepo, format_ = DatasetD.read_config(config_path)
         primary_keys = [code_flt, time_flt]  # 插入primary key
         if is_annrepo:
@@ -588,7 +588,11 @@ class DatasetProvider(BaseDataProvider):
         normalize_column_names = DatasetD.normalize_cache_fields(primary_keys + normalize_column_names)
         code_flt = ffield(code_flt) if code_flt is not None else None
         time_flt = ffield(time_flt) if time_flt is not None else None
-        dset = ds.dataset(fpath, format=format_)  # 还差不规则特征
+        if format_ == "feather":
+            flist = glob.glob(os.path.join(fpath, "*[!.json]"))
+        else:
+            flist = glob.glob(os.path.join(fpath, "**", "*"))
+        dset = ds.dataset(flist, format=format_)  # 还差不规则特征
 
         if code_flt is None:
             if time_flt is None:
@@ -615,7 +619,7 @@ class DatasetProvider(BaseDataProvider):
         :return:
         """
         # One process for one task, so that the memory will be freed quicker.
-        config_path = fpath + "_config.json"
+        config_path = os.path.join(fpath, "config.json")
         code_flt, time_flt, _, is_annrepo, format_ = DatasetD.read_config(config_path)
         primary_keys = [code_flt, time_flt]  # 插入primary key
         if is_annrepo:
@@ -623,7 +627,11 @@ class DatasetProvider(BaseDataProvider):
         column_names = primary_keys + column_names
 
         normalize_column_names = DatasetD.normalize_cache_fields(column_names)
-        dset = ds.dataset(fpath, format=format_)
+        if format_ == "feather":
+            flist = glob.glob(os.path.join(fpath, "*[!.json]"))
+        else:
+            flist = glob.glob(os.path.join(fpath, "**", "*"))
+        dset = ds.dataset(flist, format=format_)
         # 还差不规则特征
         start = time.perf_counter()
         if filt is None:
